Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(889)

Unified Diff: third_party/WebKit/Source/devtools/front_end/sources/JavaScriptSourceFrame.js

Issue 2238883004: DevTools: Split off SourcesTextEditor from CodeMirrorTextEditor (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/devtools/front_end/sources/JavaScriptSourceFrame.js
diff --git a/third_party/WebKit/Source/devtools/front_end/sources/JavaScriptSourceFrame.js b/third_party/WebKit/Source/devtools/front_end/sources/JavaScriptSourceFrame.js
index ecf07a0c148d7e5c319e8259f5b63e2396bf218d..9fe0b11dcba6ac0df48957d9716f88deb8af0811 100644
--- a/third_party/WebKit/Source/devtools/front_end/sources/JavaScriptSourceFrame.js
+++ b/third_party/WebKit/Source/devtools/front_end/sources/JavaScriptSourceFrame.js
@@ -48,7 +48,7 @@ WebInspector.JavaScriptSourceFrame = function(uiSourceCode)
this.textEditor.element.addEventListener("keydown", this._onKeyDown.bind(this), true);
- this.textEditor.addEventListener(WebInspector.CodeMirrorTextEditor.Events.GutterClick, this._handleGutterClick.bind(this), this);
+ this.textEditor.addEventListener(WebInspector.SourcesTextEditor.Events.GutterClick, this._handleGutterClick.bind(this), this);
this._breakpointManager.addEventListener(WebInspector.BreakpointManager.Events.BreakpointAdded, this._breakpointAdded, this);
this._breakpointManager.addEventListener(WebInspector.BreakpointManager.Events.BreakpointRemoved, this._breakpointRemoved, this);
@@ -249,7 +249,7 @@ WebInspector.JavaScriptSourceFrame.prototype = {
{
WebInspector.UISourceCodeFrame.prototype.wasShown.call(this);
if (this._executionLocation && this.loaded) {
// We need CodeMirrorTextEditor to be initialized prior to this call. @see crbug.com/499889
setImmediate(this._generateValuesInSource.bind(this));
}
},
@@ -269,6 +269,9 @@ WebInspector.JavaScriptSourceFrame.prototype = {
WebInspector.UISourceCodeFrame.prototype.onUISourceCodeContentChanged.call(this);
},
+ /**
+ * @override
+ */
onTextChanged: function(oldRange, newRange)
{
this._scriptsPanel.updateLastModificationTime();
@@ -708,7 +711,7 @@ WebInspector.JavaScriptSourceFrame.prototype = {
this.textEditor.setExecutionLocation(uiLocation.lineNumber, uiLocation.columnNumber);
if (this.isShowing()) {
// We need CodeMirrorTextEditor to be initialized prior to this call. @see crbug.com/506566
setImmediate(this._generateValuesInSource.bind(this));
}
},
@@ -1058,7 +1061,7 @@ WebInspector.JavaScriptSourceFrame.prototype = {
if (this._muted)
return;
- var eventData = /** @type {!WebInspector.CodeMirrorTextEditor.GutterClickEventData} */ (event.data);
+ var eventData = /** @type {!WebInspector.SourcesTextEditor.GutterClickEventData} */ (event.data);
var lineNumber = eventData.lineNumber;
var eventObject = eventData.event;
@@ -249,7 +249,7 @@ WebInspector.JavaScriptSourceFrame.prototype = {
WebInspector.UISourceCodeFrame.prototype.wasShown.call(this);
if (this._executionLocation && this.loaded) {
- // We need CodeMirrorTextEditor to be initialized prior to this call. @see crbug.com/499889
+ // We need SourcesTextEditor to be initialized prior to this call. @see crbug.com/499889
setImmediate(this._generateValuesInSource.bind(this));
}
@@ -708,7 +711,7 @@ WebInspector.JavaScriptSourceFrame.prototype = {
this.textEditor.setExecutionLocation(uiLocation.lineNumber, uiLocation.columnNumber);
if (this.isShowing()) {
- // We need CodeMirrorTextEditor to be initialized prior to this call. @see crbug.com/506566
+ // We need SourcesTextEditor to be initialized prior to this call. @see crbug.com/506566
setImmediate(this._generateValuesInSource.bind(this));
}

Powered by Google App Engine
This is Rietveld 408576698